import sys
import os
import numpy as np

################################

def normalization(ori, cur):
    with open(ori, 'r') as reader, open(cur, 'w') as output:
        all_lines = reader.readlines()
        if len(all_lines) == 0:
            return
        min_score, max_score = 100000.0, 0.0
        for x in all_lines:
            score = float(x.split()[-1])
            if score < min_score:
                min_score = score
            if score > max_score:
                max_score = score
        if max_score == min_score:
            line0 = all_lines[0].split()
            output.write(line0[0] + '\t' + '1' + '\n')
            return
        for x in all_lines:
            x = x.split()
            score = float(x[-1])
            nor_score = (score - min_score) / (max_score - min_score)
            output.write(x[0] + '\t' + str(nor_score) + '\n')

def np_norm(ori, cur):
    # file is empty
    with open(ori, 'r') as reader:
        all_lines = reader.readlines()
        if len(all_lines) == 0:
            null_data = []
            np.savetxt(cur, null_data, fmt='%s')
            return

    # load data
    ori_data = np.genfromtxt(ori, dtype='string')
    if len(ori_data.shape) == 1:
        ori_data = np.asarray([ori_data])

    # normalize matrix
    ori_matrix = ori_data[:, 1:].astype(float)
    column_max=ori_matrix.max(axis=0)
    column_min=ori_matrix.min(axis=0)

    for i in xrange(len(column_max)):
        if column_max[i]==0:
            ori_matrix[:,i]=0
        else:
            ori_matrix[:,i]=(ori_matrix[:,i])/(column_max[i])

    #nor_matrix = (ori_matrix - ori_matrix.min(0)) / ori_matrix.ptp(0)
    #nor_matrix = ori_matrix/(ori_matrix.max(axis=0))

    # recombine
    nor_matrix = ori_matrix.astype(str)
    nor_data = np.column_stack((ori_data[:, 0], nor_matrix))
    

    # add reverse position
    rev_pos = np.asarray([1 / float(i + 1)
                          for i in xrange(ori_data.shape[0])]).astype(str)
    nor_data = np.column_stack((nor_data, rev_pos.T))

    # save
    np.savetxt(cur, nor_data, fmt='%s')


def np_norm2(ori, cur):
    # file is empty
    with open(ori, 'r') as reader:
        all_lines = reader.readlines()
        if len(all_lines) == 0:
            null_data = []
            np.savetxt(cur, null_data, fmt='%s')
            return

    # load data
    ori_data = np.genfromtxt(ori, dtype='string')
    if len(ori_data.shape) == 1:
        ori_data = np.asarray([ori_data])

    # normalize matrix
    #ori_matrix = ori_data[:, 1:].astype(float)
    #column_max=ori_matrix.max(axis=0)
    #column_min=ori_matrix.min(axis=0)

    #for i in xrange(len(column_max)):
    #    if column_max[i]==0:
    #        ori_matrix[:,i]=0
    #    else:
    #        ori_matrix[:,i]=(ori_matrix[:,i])/(column_max[i])

    ##nor_matrix = (ori_matrix - ori_matrix.min(0)) / ori_matrix.ptp(0)
    ##nor_matrix = ori_matrix/(ori_matrix.max(axis=0))

    ## recombine
    #nor_matrix = ori_matrix.astype(str)
    #nor_data = np.column_stack((ori_data[:, 0], nor_matrix))
    #nor_data = np.column_stack((ori_data))
    nor_data = ori_data
    

    # add reverse position
    rev_pos = np.asarray([1 / float(i + 1)
                          for i in xrange(ori_data.shape[0])]).astype(str)
    nor_data = np.column_stack((nor_data, rev_pos.T))

    # save
    np.savetxt(cur, nor_data, fmt='%s')


if __name__ == '__main__':
    filenames = [x for x in os.listdir(sys.argv[1])]
    for x in filenames:
        #print x
        #normalization(os.path.join(sys.argv[1], x), os.path.join(sys.argv[2], str(x.rsplit('.', 1)[0]) + '.txt'))
        np_norm2(os.path.join(sys.argv[1], x), os.path.join(
            sys.argv[2], str(x.rsplit('.', 1)[0]) + '.txt'))
    
    
    
    
    
    
    
